function daysVector = getCalendarFourYearsExtended(type, startMonth)
    % This function returns the vector of days in the 48 months of a four
    % year calendar span, depending on the span type. However, please note
    % that here we are assuming ANY four year period (e.g. Feb 2014 to Feb
    % 2018 or July 1899 to July 1903).
    
    % Note: For the Gregorian Calendar, five types are possible.  We denote
    % C as a common (non-leap) year and L as a leap year. CCCL, CCLC, CLCC,
    % (LCCCL, LCCCC) (CCCCL, CCCCC)
    
    % Please note that the last CCCC case is possible because years like
    % 1900 is NOT a leap year.
    % The last two cases indicate whether we would have the spillover year
    % as a leap year or a common year, respectively.
    
    commonYearVec = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    leapYearVec = commonYearVec;
    leapYearVec(2) = 29;
    
    switch type
        case 'CCCL'
            firstYear = commonYearVec(startMonth:end);
            % Spillover year is a common year
            spillOverYear = commonYearVec(1:startMonth - 1);
            daysVector = [firstYear, commonYearVec, commonYearVec, leapYearVec, spillOverYear];
        case 'CCLC'
            firstYear = commonYearVec(startMonth:end);
            % Spillover year is a common year
            spillOverYear = commonYearVec(1:startMonth - 1);
            daysVector = [firstYear, commonYearVec, leapYearVec, commonYearVec, spillOverYear];
        case 'CLCC'
            firstYear = commonYearVec(startMonth:end);
            % Spillover year is a common year
            spillOverYear = commonYearVec(1:startMonth - 1);
            daysVector = [firstYear, leapYearVec, commonYearVec, commonYearVec, spillOverYear];
        case 'LCCCL'
            % Here the first year, as defined, is a leap year
            firstYear = leapYearVec(startMonth:end);
            % Spillover year is a leap year
            spillOverYear = leapYearVec(1:startMonth - 1);
            daysVector = [firstYear, commonYearVec, commonYearVec, commonYearVec, spillOverYear];
        case 'LCCCC'
            % Here the first year, as defined, is a leap year
            firstYear = leapYearVec(startMonth:end);
            % Spillover year is a common year (e.g. 1896 to 1900).
            spillOverYear = commonYearVec(1:startMonth - 1);
            daysVector = [firstYear, commonYearVec, commonYearVec, commonYearVec, spillOverYear];
        case 'CCCCC'
            firstYear = commonYearVec(startMonth:end);
            % Spillover year is a common year
            spillOverYear = commonYearVec(1:startMonth - 1);
            daysVector = [firstYear, commonYearVec, commonYearVec, commonYearVec, spillOverYear];
        case 'CCCCL'
            firstYear = commonYearVec(startMonth:end);
            % Spillover year is a leap year
            spillOverYear = leapYearVec(1:startMonth - 1);
            daysVector = [firstYear, commonYearVec, commonYearVec, commonYearVec, spillOverYear];
        otherwise
            error('Invalid type!');
    end
end